==> aliyun-tools-0.0.1-20180716.021925-6-sources.jar: com/jz/aliyun/beans/StsUploadInfo.java <==
package com.jz.aliyun.beans;

public class StsUploadInfo {

	private String oSSAccessKeyId;
	private String secret;
	private String host;
	private String policy;
	private String signature;
	private String key;
	private String fileName;
	private String callback;
	private long expire;
	private String uploadToken;

	private StsUploadInfo() {
	}

	public static StsUploadInfo of() {
		return new StsUploadInfo();
	}

	public String getoSSAccessKeyId() {
		return oSSAccessKeyId;
	}

	public StsUploadInfo setoSSAccessKeyId(String oSSAccessKeyId) {
		this.oSSAccessKeyId = oSSAccessKeyId;
		return this;
	}

	public String getSecret() {
		return secret;
	}

	public StsUploadInfo setSecret(String secret) {
		this.secret = secret;
		return this;
	}

	public String getHost() {
		return host;
	}

	public StsUploadInfo setHost(String host) {
		this.host = host;
		return this;
	}

	public String getPolicy() {
		return policy;
	}

	public StsUploadInfo setPolicy(String policy) {
		this.policy = policy;
		return this;
	}

	public String getSignature() {
		return signature;
	}

	public StsUploadInfo setSignature(String signature) {
		this.signature = signature;
		return this;
	}

	public String getKey() {
		return key;
	}

	public StsUploadInfo setKey(String key) {
		this.key = key;
		return this;
	}

	public String getFileName() {
		return fileName;
	}

	public StsUploadInfo setFileName(String fileName) {
		this.fileName = fileName;
		return this;
	}

	public String getCallback() {
		return callback;
	}

	public StsUploadInfo setCallback(String callback) {
		this.callback = callback;
		return this;
	}

	public long getExpire() {
		return expire;
	}

	public StsUploadInfo setExpire(long expire) {
		this.expire = expire;
		return this;
	}

	public String getUploadToken() {
		return uploadToken;
	}

	public StsUploadInfo setUploadToken(String uploadToken) {
		this.uploadToken = uploadToken;
		return this;
	}

}

==> aliyun-tools-0.0.2-20190319.062308-16-sources.jar: com/jz/aliyun/beans/StsUploadInfo.java <==
package com.jz.aliyun.beans;

import com.fasterxml.jackson.annotation.JsonProperty;

public class StsUploadInfo {

	private String accessKeyId;
	private String secret;
	private String host;
	private String policy;
	private String signature;
	private String key;
	private String fileName;
	private String callback;
	private long expire;
	private String uploadToken;

	private StsUploadInfo() {
	}

	public static StsUploadInfo of() {
		return new StsUploadInfo();
	}
	
	@JsonProperty(value = "OSSAccessKeyId")
	public String getAccessKeyId() {
		return accessKeyId;
	}

	public StsUploadInfo setAccessKeyId(String accessKeyId) {
		this.accessKeyId = accessKeyId;
		return this;
	}
	
	public String getSecret() {
		return secret;
	}

	public StsUploadInfo setSecret(String secret) {
		this.secret = secret;
		return this;
	}

	public String getHost() {
		return host;
	}

	public StsUploadInfo setHost(String host) {
		this.host = host;
		return this;
	}

	public String getPolicy() {
		return policy;
	}

	public StsUploadInfo setPolicy(String policy) {
		this.policy = policy;
		return this;
	}

	public String getSignature() {
		return signature;
	}

	public StsUploadInfo setSignature(String signature) {
		this.signature = signature;
		return this;
	}

	public String getKey() {
		return key;
	}

	public StsUploadInfo setKey(String key) {
		this.key = key;
		return this;
	}

	public String getFileName() {
		return fileName;
	}

	public StsUploadInfo setFileName(String fileName) {
		this.fileName = fileName;
		return this;
	}

	public String getCallback() {
		return callback;
	}

	public StsUploadInfo setCallback(String callback) {
		this.callback = callback;
		return this;
	}

	public long getExpire() {
		return expire;
	}

	public StsUploadInfo setExpire(long expire) {
		this.expire = expire;
		return this;
	}

	public String getUploadToken() {
		return uploadToken;
	}

	public StsUploadInfo setUploadToken(String uploadToken) {
		this.uploadToken = uploadToken;
		return this;
	}

}
